import sys
import typing


def copy():
    '''Copy the material settings and nodes 

    '''

    pass


def new():
    '''Add a new material 

    '''

    pass


def paste():
    '''Paste the material settings and nodes 

    '''

    pass


def sss_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Subsurface Scattering Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass



import sys
import typing


class GPUOffscreen:
    '''unbind(restore=True) '''

    color_texture: int = None
    '''Color texture. 

    :type: int
    '''

    height: int = None
    '''Texture height. 

    :type: int
    '''

    width: int = None
    '''Texture width. 

    :type: int
    '''



import sys
import typing
import bpy


def addon_disable(module: str = ""):
    '''Disable an add-on 

    :param module: Module, Module name of the add-on to disable 
    :type module: str
    '''

    pass


def addon_enable(module: str = ""):
    '''Enable an add-on 

    :param module: Module, Module name of the add-on to enable 
    :type module: str
    '''

    pass


def addon_expand(module: str = ""):
    '''Display information and preferences for this add-on 

    :param module: Module, Module name of the add-on to expand 
    :type module: str
    '''

    pass


def addon_install(overwrite: bool = True,
                  target: typing.Union[str, int] = 'DEFAULT',
                  filepath: str = "",
                  filter_folder: bool = True,
                  filter_python: bool = True,
                  filter_glob: str = "*.py;*.zip"):
    '''Install an add-on 

    :param overwrite: Overwrite, Remove existing add-ons with the same ID 
    :type overwrite: bool
    :param target: Target Path 
    :type target: typing.Union[str, int]
    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_python: Filter python 
    :type filter_python: bool
    :param filter_glob: filter_glob 
    :type filter_glob: str
    '''

    pass


def addon_refresh():
    '''Scan add-on directories for new modules 

    '''

    pass


def addon_remove(module: str = ""):
    '''Delete the add-on from the file system 

    :param module: Module, Module name of the add-on to remove 
    :type module: str
    '''

    pass


def addon_userpref_show(module: str = ""):
    '''Show add-on user preferences 

    :param module: Module, Module name of the add-on to expand 
    :type module: str
    '''

    pass


def alembic_export(filepath: str = "",
                   check_existing: bool = True,
                   filter_blender: bool = False,
                   filter_backup: bool = False,
                   filter_image: bool = False,
                   filter_movie: bool = False,
                   filter_python: bool = False,
                   filter_font: bool = False,
                   filter_sound: bool = False,
                   filter_text: bool = False,
                   filter_btx: bool = False,
                   filter_collada: bool = False,
                   filter_alembic: bool = True,
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
                   display_type: typing.Union[str, int] = 'DEFAULT',
                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                   start: int = -2147483648,
                   end: int = -2147483648,
                   xsamples: int = 1,
                   gsamples: int = 1,
                   sh_open: float = 0.0,
                   sh_close: float = 1.0,
                   selected: bool = False,
                   renderable_only: bool = True,
                   visible_layers_only: bool = False,
                   flatten: bool = False,
                   uvs: bool = True,
                   packuv: bool = True,
                   normals: bool = True,
                   vcolors: bool = False,
                   face_sets: bool = False,
                   subdiv_schema: bool = False,
                   apply_subdiv: bool = False,
                   compression_type: typing.Union[str, int] = 'OGAWA',
                   global_scale: float = 1.0,
                   triangulate: bool = False,
                   quad_method: typing.Union[str, int] = 'SHORTEST_DIAGONAL',
                   ngon_method: typing.Union[str, int] = 'BEAUTY',
                   export_hair: bool = True,
                   export_particles: bool = True,
                   as_background_job: bool = True,
                   init_scene_frame_range=False):
    '''Export current scene in an Alembic archive 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param start: Start Frame, Start frame of the export, use the default value to take the start frame of the current scene 
    :type start: int
    :param end: End Frame, End frame of the export, use the default value to take the end frame of the current scene 
    :type end: int
    :param xsamples: Transform Samples, Number of times per frame transformations are sampled 
    :type xsamples: int
    :param gsamples: Geometry Samples, Number of times per frame object data are sampled 
    :type gsamples: int
    :param sh_open: Shutter Open, Time at which the shutter is open 
    :type sh_open: float
    :param sh_close: Shutter Close, Time at which the shutter is closed 
    :type sh_close: float
    :param selected: Selected Objects Only, Export only selected objects 
    :type selected: bool
    :param renderable_only: Renderable Objects Only, Export only objects marked renderable in the outliner 
    :type renderable_only: bool
    :param visible_layers_only: Visible Layers Only, Export only objects in visible layers 
    :type visible_layers_only: bool
    :param flatten: Flatten Hierarchy, Do not preserve objects’ parent/children relationship 
    :type flatten: bool
    :param uvs: UVs, Export UVs 
    :type uvs: bool
    :param packuv: Pack UV Islands, Export UVs with packed island 
    :type packuv: bool
    :param normals: Normals, Export normals 
    :type normals: bool
    :param vcolors: Vertex Colors, Export vertex colors 
    :type vcolors: bool
    :param face_sets: Face Sets, Export per face shading group assignments 
    :type face_sets: bool
    :param subdiv_schema: Use Subdivision Schema, Export meshes using Alembic’s subdivision schema 
    :type subdiv_schema: bool
    :param apply_subdiv: Apply Subsurf, Export subdivision surfaces as meshes 
    :type apply_subdiv: bool
    :param compression_type: Compression 
    :type compression_type: typing.Union[str, int]
    :param global_scale: Scale, Value by which to enlarge or shrink the objects with respect to the world’s origin 
    :type global_scale: float
    :param triangulate: Triangulate, Export Polygons (Quads & NGons) as Triangles 
    :type triangulate: bool
    :param quad_method: Quad Method, Method for splitting the quads into trianglesBEAUTY Beauty , Split the quads in nice triangles, slower method.FIXED Fixed, Split the quads on the first and third vertices.FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices.SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices. 
    :type quad_method: typing.Union[str, int]
    :param ngon_method: Polygon Method, Method for splitting the polygons into trianglesBEAUTY Beauty , Split the quads in nice triangles, slower method.FIXED Fixed, Split the quads on the first and third vertices.FIXED_ALTERNATE Fixed Alternate, Split the quads on the 2nd and 4th vertices.SHORTEST_DIAGONAL Shortest Diagonal, Split the quads based on the distance between the vertices. 
    :type ngon_method: typing.Union[str, int]
    :param export_hair: Export Hair, Exports hair particle systems as animated curves 
    :type export_hair: bool
    :param export_particles: Export Particles, Exports non-hair particle systems 
    :type export_particles: bool
    :param as_background_job: Run as Background Job, Enable this to run the import in the background, disable to block Blender while importing 
    :type as_background_job: bool
    '''

    pass


def alembic_import(filepath: str = "",
                   check_existing: bool = True,
                   filter_blender: bool = False,
                   filter_backup: bool = False,
                   filter_image: bool = False,
                   filter_movie: bool = False,
                   filter_python: bool = False,
                   filter_font: bool = False,
                   filter_sound: bool = False,
                   filter_text: bool = False,
                   filter_btx: bool = False,
                   filter_collada: bool = False,
                   filter_alembic: bool = True,
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
                   display_type: typing.Union[str, int] = 'DEFAULT',
                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                   scale: float = 1.0,
                   set_frame_range: bool = True,
                   validate_meshes: bool = False,
                   is_sequence: bool = False,
                   as_background_job: bool = True):
    '''Load an Alembic archive 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param scale: Scale, Value by which to enlarge or shrink the objects with respect to the world’s origin 
    :type scale: float
    :param set_frame_range: Set Frame Range, If checked, update scene’s start and end frame to match those of the Alembic archive 
    :type set_frame_range: bool
    :param validate_meshes: Validate Meshes, Check imported mesh objects for invalid data (slow) 
    :type validate_meshes: bool
    :param is_sequence: Is Sequence, Set to true if the cache is split into separate files 
    :type is_sequence: bool
    :param as_background_job: Run as Background Job, Enable this to run the export in the background, disable to block Blender while exporting 
    :type as_background_job: bool
    '''

    pass


def app_template_install(overwrite: bool = True,
                         filepath: str = "",
                         filter_folder: bool = True,
                         filter_glob: str = "*.zip"):
    '''Install an application-template 

    :param overwrite: Overwrite, Remove existing template with the same ID 
    :type overwrite: bool
    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_glob: filter_glob 
    :type filter_glob: str
    '''

    pass


def appconfig_activate(filepath: str = ""):
    '''Undocumented 

    :param filepath: filepath 
    :type filepath: str
    '''

    pass


def appconfig_default():
    '''Undocumented 

    '''

    pass


def append(filepath: str = "",
           directory: str = "",
           filename: str = "",
           files: typing.List['bpy.types.OperatorFileListElement'] = None,
           filter_blender: bool = True,
           filter_backup: bool = False,
           filter_image: bool = False,
           filter_movie: bool = False,
           filter_python: bool = False,
           filter_font: bool = False,
           filter_sound: bool = False,
           filter_text: bool = False,
           filter_btx: bool = False,
           filter_collada: bool = False,
           filter_alembic: bool = False,
           filter_folder: bool = True,
           filter_blenlib: bool = True,
           filemode: int = 1,
           display_type: typing.Union[str, int] = 'DEFAULT',
           sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
           link: bool = False,
           autoselect: bool = True,
           active_layer: bool = True,
           instance_groups: bool = False,
           set_fake: bool = False,
           use_recursive: bool = True):
    '''Append from a Library .blend file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param directory: Directory, Directory of the file 
    :type directory: str
    :param filename: File Name, Name of the file 
    :type filename: str
    :param files: Files 
    :type files: typing.List['bpy.types.OperatorFileListElement']
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param link: Link, Link the objects or data-blocks rather than appending 
    :type link: bool
    :param autoselect: Select, Select new objects 
    :type autoselect: bool
    :param active_layer: Active Layer, Put new objects on the active layer 
    :type active_layer: bool
    :param instance_groups: Instance Groups, Create Dupli-Group instances for each group 
    :type instance_groups: bool
    :param set_fake: Fake User, Set Fake User for appended items (except Objects and Groups) 
    :type set_fake: bool
    :param use_recursive: Localize All, Localize all appended data, including those indirectly linked from other libraries 
    :type use_recursive: bool
    '''

    pass


def blenderplayer_start():
    '''Launch the blender-player with the current blend-file 

    '''

    pass


def call_menu(name: str = ""):
    '''Call (draw) a pre-defined menu 

    :param name: Name, Name of the menu 
    :type name: str
    '''

    pass


def call_menu_pie(name: str = ""):
    '''Call (draw) a pre-defined pie menu 

    :param name: Name, Name of the pie menu 
    :type name: str
    '''

    pass


def collada_export(
        filepath: str = "",
        check_existing: bool = True,
        filter_blender: bool = False,
        filter_backup: bool = False,
        filter_image: bool = False,
        filter_movie: bool = False,
        filter_python: bool = False,
        filter_font: bool = False,
        filter_sound: bool = False,
        filter_text: bool = False,
        filter_btx: bool = False,
        filter_collada: bool = True,
        filter_alembic: bool = False,
        filter_folder: bool = True,
        filter_blenlib: bool = False,
        filemode: int = 8,
        display_type: typing.Union[str, int] = 'DEFAULT',
        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
        apply_modifiers: bool = False,
        export_mesh_type: int = 0,
        export_mesh_type_selection: typing.Union[str, int] = 'view',
        selected: bool = False,
        include_children: bool = False,
        include_armatures: bool = False,
        include_shapekeys: bool = True,
        deform_bones_only: bool = False,
        active_uv_only: bool = False,
        use_texture_copies: bool = True,
        triangulate: bool = True,
        use_object_instantiation: bool = True,
        use_blender_profile: bool = True,
        sort_by_name: bool = False,
        export_transformation_type: int = 0,
        export_transformation_type_selection: typing.
        Union[str, int] = 'matrix',
        export_texture_type: int = 0,
        export_texture_type_selection: typing.Union[str, int] = 'mat',
        open_sim: bool = False,
        limit_precision: bool = False,
        keep_bind_info: bool = False):
    '''Save a Collada file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param apply_modifiers: Apply Modifiers, Apply modifiers to exported mesh (non destructive)) 
    :type apply_modifiers: bool
    :param export_mesh_type: Resolution, Modifier resolution for export 
    :type export_mesh_type: int
    :param export_mesh_type_selection: Resolution, Modifier resolution for exportview View, Apply modifier’s view settings.render Render, Apply modifier’s render settings. 
    :type export_mesh_type_selection: typing.Union[str, int]
    :param selected: Selection Only, Export only selected elements 
    :type selected: bool
    :param include_children: Include Children, Export all children of selected objects (even if not selected) 
    :type include_children: bool
    :param include_armatures: Include Armatures, Export related armatures (even if not selected) 
    :type include_armatures: bool
    :param include_shapekeys: Include Shape Keys, Export all Shape Keys from Mesh Objects 
    :type include_shapekeys: bool
    :param deform_bones_only: Deform Bones only, Only export deforming bones with armatures 
    :type deform_bones_only: bool
    :param active_uv_only: Only Selected UV Map, Export only the selected UV Map 
    :type active_uv_only: bool
    :param use_texture_copies: Copy, Copy textures to same folder where the .dae file is exported 
    :type use_texture_copies: bool
    :param triangulate: Triangulate, Export Polygons (Quads & NGons) as Triangles 
    :type triangulate: bool
    :param use_object_instantiation: Use Object Instances, Instantiate multiple Objects from same Data 
    :type use_object_instantiation: bool
    :param use_blender_profile: Use Blender Profile, Export additional Blender specific information (for material, shaders, bones, etc.) 
    :type use_blender_profile: bool
    :param sort_by_name: Sort by Object name, Sort exported data by Object name 
    :type sort_by_name: bool
    :param export_transformation_type: Transform, Transformation type for translation, scale and rotation 
    :type export_transformation_type: int
    :param export_transformation_type_selection: Transform, Transformation type for translation, scale and rotationmatrix Matrix, Use <matrix> to specify transformations.transrotloc TransRotLoc, Use <translate>, <rotate>, <scale> to specify transformations. 
    :type export_transformation_type_selection: typing.Union[str, int]
    :param export_texture_type: Texture Type, Type for exported Textures (UV or MAT) 
    :type export_texture_type: int
    :param export_texture_type_selection: Texture Type, Type for exported Textures (UV or MAT)mat Materials, Export Materials.uv UV Textures, Export UV Textures (Face textures) as materials. 
    :type export_texture_type_selection: typing.Union[str, int]
    :param open_sim: Export to SL/OpenSim, Compatibility mode for SL, OpenSim and other compatible online worlds 
    :type open_sim: bool
    :param limit_precision: Limit Precision, Reduce the precision of the exported data to 6 digits 
    :type limit_precision: bool
    :param keep_bind_info: Keep Bind Info, Store Bindpose information in custom bone properties for later use during Collada export 
    :type keep_bind_info: bool
    '''

    pass


def collada_import(filepath: str = "",
                   filter_blender: bool = False,
                   filter_backup: bool = False,
                   filter_image: bool = False,
                   filter_movie: bool = False,
                   filter_python: bool = False,
                   filter_font: bool = False,
                   filter_sound: bool = False,
                   filter_text: bool = False,
                   filter_btx: bool = False,
                   filter_collada: bool = True,
                   filter_alembic: bool = False,
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
                   display_type: typing.Union[str, int] = 'DEFAULT',
                   sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                   import_units: bool = False,
                   fix_orientation: bool = False,
                   find_chains: bool = False,
                   auto_connect: bool = False,
                   min_chain_length: int = 0,
                   keep_bind_info: bool = False):
    '''Load a Collada file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param import_units: Import Units, If disabled match import to Blender’s current Unit settings, otherwise use the settings from the Imported scene 
    :type import_units: bool
    :param fix_orientation: Fix Leaf Bones, Fix Orientation of Leaf Bones (Collada does only support Joints) 
    :type fix_orientation: bool
    :param find_chains: Find Bone Chains, Find best matching Bone Chains and ensure bones in chain are connected 
    :type find_chains: bool
    :param auto_connect: Auto Connect, Set use_connect for parent bones which have exactly one child bone 
    :type auto_connect: bool
    :param min_chain_length: Minimum Chain Length, When searching Bone Chains disregard chains of length below this value 
    :type min_chain_length: int
    :param keep_bind_info: Keep Bind Info, Store Bindpose information in custom bone properties for later use during Collada export 
    :type keep_bind_info: bool
    '''

    pass


def context_collection_boolean_set(data_path_iter: str = "",
                                   data_path_item: str = "",
                                   type: typing.Union[str, int] = 'TOGGLE'):
    '''Set boolean values for a collection of items 

    :param data_path_iter: data_path_iter, The data path relative to the context, must point to an iterable 
    :type data_path_iter: str
    :param data_path_item: data_path_item, The data path from each iterable to the value (int or float) 
    :type data_path_item: str
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def context_cycle_array(data_path: str = "", reverse: bool = False):
    '''Set a context array value (useful for cycling the active mesh edit mode) 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param reverse: Reverse, Cycle backwards 
    :type reverse: bool
    '''

    pass


def context_cycle_enum(data_path: str = "",
                       reverse: bool = False,
                       wrap: bool = False):
    '''Toggle a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param reverse: Reverse, Cycle backwards 
    :type reverse: bool
    :param wrap: Wrap, Wrap back to the first/last values 
    :type wrap: bool
    '''

    pass


def context_cycle_int(data_path: str = "",
                      reverse: bool = False,
                      wrap: bool = False):
    '''Set a context value (useful for cycling active material, vertex keys, groups, etc.) 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param reverse: Reverse, Cycle backwards 
    :type reverse: bool
    :param wrap: Wrap, Wrap back to the first/last values 
    :type wrap: bool
    '''

    pass


def context_menu_enum(data_path: str = ""):
    '''Undocumented 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    '''

    pass


def context_modal_mouse(data_path_iter: str = "",
                        data_path_item: str = "",
                        header_text: str = "",
                        input_scale: float = 0.01,
                        invert: bool = False,
                        initial_x: int = 0):
    '''Adjust arbitrary values with mouse input 

    :param data_path_iter: data_path_iter, The data path relative to the context, must point to an iterable 
    :type data_path_iter: str
    :param data_path_item: data_path_item, The data path from each iterable to the value (int or float) 
    :type data_path_item: str
    :param header_text: Header Text, Text to display in header during scale 
    :type header_text: str
    :param input_scale: input_scale, Scale the mouse movement by this value before applying the delta 
    :type input_scale: float
    :param invert: invert, Invert the mouse input 
    :type invert: bool
    :param initial_x: initial_x 
    :type initial_x: int
    '''

    pass


def context_pie_enum(data_path: str = ""):
    '''Undocumented 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    '''

    pass


def context_scale_float(data_path: str = "", value: float = 1.0):
    '''Scale a float context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assign value 
    :type value: float
    '''

    pass


def context_scale_int(data_path: str = "",
                      value: float = 1.0,
                      always_step: bool = True):
    '''Scale an int context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assign value 
    :type value: float
    :param always_step: Always Step, Always adjust the value by a minimum of 1 when ‘value’ is not 1.0 
    :type always_step: bool
    '''

    pass


def context_set_boolean(data_path: str = "", value: bool = True):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assignment value 
    :type value: bool
    '''

    pass


def context_set_enum(data_path: str = "", value: str = ""):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assignment value (as a string) 
    :type value: str
    '''

    pass


def context_set_float(data_path: str = "",
                      value: float = 0.0,
                      relative: bool = False):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assignment value 
    :type value: float
    :param relative: Relative, Apply relative to the current value (delta) 
    :type relative: bool
    '''

    pass


def context_set_id(data_path: str = "", value: str = ""):
    '''Set a context value to an ID data-block 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assign value 
    :type value: str
    '''

    pass


def context_set_int(data_path: str = "",
                    value: int = 0,
                    relative: bool = False):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assign value 
    :type value: int
    :param relative: Relative, Apply relative to the current value (delta) 
    :type relative: bool
    '''

    pass


def context_set_string(data_path: str = "", value: str = ""):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assign value 
    :type value: str
    '''

    pass


def context_set_value(data_path: str = "", value: str = ""):
    '''Set a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value: Value, Assignment value (as a string) 
    :type value: str
    '''

    pass


def context_toggle(data_path: str = ""):
    '''Toggle a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    '''

    pass


def context_toggle_enum(data_path: str = "",
                        value_1: str = "",
                        value_2: str = ""):
    '''Toggle a context value 

    :param data_path: Context Attributes, RNA context string 
    :type data_path: str
    :param value_1: Value, Toggle enum 
    :type value_1: str
    :param value_2: Value, Toggle enum 
    :type value_2: str
    '''

    pass


def copy_prev_settings():
    '''Copy settings from previous version 

    '''

    pass


def debug_menu(debug_value: int = 0):
    '''Open a popup to set the debug level 

    :param debug_value: Debug Value 
    :type debug_value: int
    '''

    pass


def dependency_relations():
    '''Print dependency graph relations to the console 

    '''

    pass


def doc_view(doc_id: str = ""):
    '''Load online reference docs 

    :param doc_id: Doc ID 
    :type doc_id: str
    '''

    pass


def doc_view_manual(doc_id: str = ""):
    '''Load online manual 

    :param doc_id: Doc ID 
    :type doc_id: str
    '''

    pass


def doc_view_manual_ui_context():
    '''View a context based online manual in a web browser 

    '''

    pass


def interaction_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove an Application Interaction Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def interface_theme_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a theme preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def keyconfig_activate(filepath: str = ""):
    '''Undocumented 

    :param filepath: filepath 
    :type filepath: str
    '''

    pass


def keyconfig_export(filepath: str = "keymap.py",
                     filter_folder: bool = True,
                     filter_text: bool = True,
                     filter_python: bool = True):
    '''Export key configuration to a python script 

    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_text: Filter text 
    :type filter_text: bool
    :param filter_python: Filter python 
    :type filter_python: bool
    '''

    pass


def keyconfig_import(filepath: str = "keymap.py",
                     filter_folder: bool = True,
                     filter_text: bool = True,
                     filter_python: bool = True,
                     keep_original: bool = True):
    '''Import key configuration from a python script 

    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_text: Filter text 
    :type filter_text: bool
    :param filter_python: Filter python 
    :type filter_python: bool
    :param keep_original: Keep original, Keep original file after copying to configuration folder 
    :type keep_original: bool
    '''

    pass


def keyconfig_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Key-config Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def keyconfig_remove():
    '''Remove key config 

    '''

    pass


def keyconfig_test():
    '''Test key-config for conflicts 

    '''

    pass


def keyitem_add():
    '''Add key map item 

    '''

    pass


def keyitem_remove(item_id: int = 0):
    '''Remove key map item 

    :param item_id: Item Identifier, Identifier of the item to remove 
    :type item_id: int
    '''

    pass


def keyitem_restore(item_id: int = 0):
    '''Restore key map item 

    :param item_id: Item Identifier, Identifier of the item to remove 
    :type item_id: int
    '''

    pass


def keymap_restore(all: bool = False):
    '''Restore key map(s) 

    :param all: All Keymaps, Restore all keymaps to default 
    :type all: bool
    '''

    pass


def lib_reload(library: str = "",
               filepath: str = "",
               directory: str = "",
               filename: str = "",
               filter_blender: bool = True,
               filter_backup: bool = False,
               filter_image: bool = False,
               filter_movie: bool = False,
               filter_python: bool = False,
               filter_font: bool = False,
               filter_sound: bool = False,
               filter_text: bool = False,
               filter_btx: bool = False,
               filter_collada: bool = False,
               filter_alembic: bool = False,
               filter_folder: bool = True,
               filter_blenlib: bool = False,
               filemode: int = 8,
               relative_path: bool = True,
               display_type: typing.Union[str, int] = 'DEFAULT',
               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
    '''Reload the given library 

    :param library: Library, Library to reload 
    :type library: str
    :param filepath: File Path, Path to file 
    :type filepath: str
    :param directory: Directory, Directory of the file 
    :type directory: str
    :param filename: File Name, Name of the file 
    :type filename: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    '''

    pass


def lib_relocate(
        library: str = "",
        filepath: str = "",
        directory: str = "",
        filename: str = "",
        files: typing.List['bpy.types.OperatorFileListElement'] = None,
        filter_blender: bool = True,
        filter_backup: bool = False,
        filter_image: bool = False,
        filter_movie: bool = False,
        filter_python: bool = False,
        filter_font: bool = False,
        filter_sound: bool = False,
        filter_text: bool = False,
        filter_btx: bool = False,
        filter_collada: bool = False,
        filter_alembic: bool = False,
        filter_folder: bool = True,
        filter_blenlib: bool = False,
        filemode: int = 8,
        relative_path: bool = True,
        display_type: typing.Union[str, int] = 'DEFAULT',
        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
    '''Relocate the given library to one or several others 

    :param library: Library, Library to relocate 
    :type library: str
    :param filepath: File Path, Path to file 
    :type filepath: str
    :param directory: Directory, Directory of the file 
    :type directory: str
    :param filename: File Name, Name of the file 
    :type filename: str
    :param files: Files 
    :type files: typing.List['bpy.types.OperatorFileListElement']
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    '''

    pass


def link(filepath: str = "",
         directory: str = "",
         filename: str = "",
         files: typing.List['bpy.types.OperatorFileListElement'] = None,
         filter_blender: bool = True,
         filter_backup: bool = False,
         filter_image: bool = False,
         filter_movie: bool = False,
         filter_python: bool = False,
         filter_font: bool = False,
         filter_sound: bool = False,
         filter_text: bool = False,
         filter_btx: bool = False,
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = True,
         filemode: int = 1,
         relative_path: bool = True,
         display_type: typing.Union[str, int] = 'DEFAULT',
         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         link: bool = True,
         autoselect: bool = True,
         active_layer: bool = True,
         instance_groups: bool = True):
    '''Link from a Library .blend file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param directory: Directory, Directory of the file 
    :type directory: str
    :param filename: File Name, Name of the file 
    :type filename: str
    :param files: Files 
    :type files: typing.List['bpy.types.OperatorFileListElement']
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param link: Link, Link the objects or data-blocks rather than appending 
    :type link: bool
    :param autoselect: Select, Select new objects 
    :type autoselect: bool
    :param active_layer: Active Layer, Put new objects on the active layer 
    :type active_layer: bool
    :param instance_groups: Instance Groups, Create Dupli-Group instances for each group 
    :type instance_groups: bool
    '''

    pass


def memory_statistics():
    '''Print memory statistics to the console 

    '''

    pass


def open_mainfile(filepath: str = "",
                  filter_blender: bool = True,
                  filter_backup: bool = False,
                  filter_image: bool = False,
                  filter_movie: bool = False,
                  filter_python: bool = False,
                  filter_font: bool = False,
                  filter_sound: bool = False,
                  filter_text: bool = False,
                  filter_btx: bool = False,
                  filter_collada: bool = False,
                  filter_alembic: bool = False,
                  filter_folder: bool = True,
                  filter_blenlib: bool = False,
                  filemode: int = 8,
                  display_type: typing.Union[str, int] = 'DEFAULT',
                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                  load_ui: bool = True,
                  use_scripts: bool = True):
    '''Open a Blender file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param load_ui: Load UI, Load user interface setup in the .blend file 
    :type load_ui: bool
    :param use_scripts: Trusted Source, Allow .blend file to execute scripts automatically, default available from system preferences 
    :type use_scripts: bool
    '''

    pass


def operator_cheat_sheet():
    '''List all the Operators in a text-block, useful for scripting 

    '''

    pass


def operator_defaults():
    '''Set the active operator to its default values 

    '''

    pass


def operator_pie_enum(data_path: str = "", prop_string: str = ""):
    '''Undocumented 

    :param data_path: Operator, Operator name (in python as string) 
    :type data_path: str
    :param prop_string: Property, Property name (as a string) 
    :type prop_string: str
    '''

    pass


def operator_preset_add(name: str = "",
                        remove_active: bool = False,
                        operator: str = ""):
    '''Add or remove an Operator Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    :param operator: Operator 
    :type operator: str
    '''

    pass


def path_open(filepath: str = ""):
    '''Open a path in a file browser 

    :param filepath: filepath 
    :type filepath: str
    '''

    pass


def previews_batch_clear(
        files: typing.List['bpy.types.OperatorFileListElement'] = None,
        directory: str = "",
        filter_blender: bool = True,
        filter_folder: bool = True,
        use_scenes: bool = True,
        use_groups: bool = True,
        use_objects: bool = True,
        use_intern_data: bool = True,
        use_trusted: bool = False,
        use_backups: bool = True):
    '''Clear selected .blend file’s previews 

    :param files: files 
    :type files: typing.List['bpy.types.OperatorFileListElement']
    :param directory: directory 
    :type directory: str
    :param filter_blender: filter_blender 
    :type filter_blender: bool
    :param filter_folder: filter_folder 
    :type filter_folder: bool
    :param use_scenes: Scenes, Clear scenes’ previews 
    :type use_scenes: bool
    :param use_groups: Groups, Clear groups’ previews 
    :type use_groups: bool
    :param use_objects: Objects, Clear objects’ previews 
    :type use_objects: bool
    :param use_intern_data: Mat/Tex/…, Clear ‘internal’ previews (materials, textures, images, etc.) 
    :type use_intern_data: bool
    :param use_trusted: Trusted Blend Files, Enable python evaluation for selected files 
    :type use_trusted: bool
    :param use_backups: Save Backups, Keep a backup (.blend1) version of the files when saving with cleared previews 
    :type use_backups: bool
    '''

    pass


def previews_batch_generate(
        files: typing.List['bpy.types.OperatorFileListElement'] = None,
        directory: str = "",
        filter_blender: bool = True,
        filter_folder: bool = True,
        use_scenes: bool = True,
        use_groups: bool = True,
        use_objects: bool = True,
        use_intern_data: bool = True,
        use_trusted: bool = False,
        use_backups: bool = True):
    '''Generate selected .blend file’s previews 

    :param files: files 
    :type files: typing.List['bpy.types.OperatorFileListElement']
    :param directory: directory 
    :type directory: str
    :param filter_blender: filter_blender 
    :type filter_blender: bool
    :param filter_folder: filter_folder 
    :type filter_folder: bool
    :param use_scenes: Scenes, Generate scenes’ previews 
    :type use_scenes: bool
    :param use_groups: Groups, Generate groups’ previews 
    :type use_groups: bool
    :param use_objects: Objects, Generate objects’ previews 
    :type use_objects: bool
    :param use_intern_data: Mat/Tex/…, Generate ‘internal’ previews (materials, textures, images, etc.) 
    :type use_intern_data: bool
    :param use_trusted: Trusted Blend Files, Enable python evaluation for selected files 
    :type use_trusted: bool
    :param use_backups: Save Backups, Keep a backup (.blend1) version of the files when saving with generated previews 
    :type use_backups: bool
    '''

    pass


def previews_clear(id_type: typing.Set[typing.Union[str, int]] = {
        'GROUP', 'IMAGE', 'LAMP', 'MATERIAL', 'OBJECT', 'SCENE', 'TEXTURE',
        'WORLD'
}):
    '''Clear data-block previews (only for some types like objects, materials, textures, etc.) 

    :param id_type: Data-Block Type, Which data-block previews to clear 
    :type id_type: typing.Set[typing.Union[str, int]]
    '''

    pass


def previews_ensure():
    '''Ensure data-block previews are available and up-to-date (to be saved in .blend file, only for some types like materials, textures, etc.) 

    '''

    pass


def properties_add(data_path: str = ""):
    '''Undocumented 

    :param data_path: Property Edit, Property data_path edit 
    :type data_path: str
    '''

    pass


def properties_context_change(context: str = ""):
    '''Jump to a different tab inside the properties editor 

    :param context: Context 
    :type context: str
    '''

    pass


def properties_edit(data_path: str = "",
                    property: str = "",
                    value: str = "",
                    min: float = -10000,
                    max: float = 10000.0,
                    use_soft_limits: bool = False,
                    soft_min: float = -10000,
                    soft_max: float = 10000.0,
                    description: str = ""):
    '''Undocumented 

    :param data_path: Property Edit, Property data_path edit 
    :type data_path: str
    :param property: Property Name, Property name edit 
    :type property: str
    :param value: Property Value, Property value edit 
    :type value: str
    :param min: Min 
    :type min: float
    :param max: Max 
    :type max: float
    :param use_soft_limits: Use Soft Limits 
    :type use_soft_limits: bool
    :param soft_min: Min 
    :type soft_min: float
    :param soft_max: Max 
    :type soft_max: float
    :param description: Tooltip 
    :type description: str
    '''

    pass


def properties_remove(data_path: str = "", property: str = ""):
    '''Internal use (edit a property data_path) 

    :param data_path: Property Edit, Property data_path edit 
    :type data_path: str
    :param property: Property Name, Property name edit 
    :type property: str
    '''

    pass


def quit_blender():
    '''Quit Blender 

    '''

    pass


def radial_control(data_path_primary: str = "",
                   data_path_secondary: str = "",
                   use_secondary: str = "",
                   rotation_path: str = "",
                   color_path: str = "",
                   fill_color_path: str = "",
                   fill_color_override_path: str = "",
                   fill_color_override_test_path: str = "",
                   zoom_path: str = "",
                   image_id: str = "",
                   secondary_tex: bool = False):
    '''Set some size property (like e.g. brush size) with mouse wheel 

    :param data_path_primary: Primary Data Path, Primary path of property to be set by the radial control 
    :type data_path_primary: str
    :param data_path_secondary: Secondary Data Path, Secondary path of property to be set by the radial control 
    :type data_path_secondary: str
    :param use_secondary: Use Secondary, Path of property to select between the primary and secondary data paths 
    :type use_secondary: str
    :param rotation_path: Rotation Path, Path of property used to rotate the texture display 
    :type rotation_path: str
    :param color_path: Color Path, Path of property used to set the color of the control 
    :type color_path: str
    :param fill_color_path: Fill Color Path, Path of property used to set the fill color of the control 
    :type fill_color_path: str
    :param fill_color_override_path: Fill Color Override Path 
    :type fill_color_override_path: str
    :param fill_color_override_test_path: Fill Color Override Test 
    :type fill_color_override_test_path: str
    :param zoom_path: Zoom Path, Path of property used to set the zoom level for the control 
    :type zoom_path: str
    :param image_id: Image ID, Path of ID that is used to generate an image for the control 
    :type image_id: str
    :param secondary_tex: Secondary Texture, Tweak brush secondary/mask texture 
    :type secondary_tex: bool
    '''

    pass


def read_factory_settings(app_template="Template", use_empty: bool = False):
    '''Load default file and user preferences 

    :param use_empty: Empty 
    :type use_empty: bool
    '''

    pass


def read_history():
    '''Reloads history and bookmarks 

    '''

    pass


def read_homefile(filepath: str = "",
                  load_ui: bool = True,
                  use_empty: bool = False,
                  use_splash: bool = False,
                  app_template="Template"):
    '''Open the default file (doesn’t save the current file) 

    :param filepath: File Path, Path to an alternative start-up file 
    :type filepath: str
    :param load_ui: Load UI, Load user interface setup from the .blend file 
    :type load_ui: bool
    :param use_empty: Empty 
    :type use_empty: bool
    :param use_splash: Splash 
    :type use_splash: bool
    '''

    pass


def recover_auto_save(filepath: str = "",
                      filter_blender: bool = True,
                      filter_backup: bool = False,
                      filter_image: bool = False,
                      filter_movie: bool = False,
                      filter_python: bool = False,
                      filter_font: bool = False,
                      filter_sound: bool = False,
                      filter_text: bool = False,
                      filter_btx: bool = False,
                      filter_collada: bool = False,
                      filter_alembic: bool = False,
                      filter_folder: bool = False,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
                      display_type: typing.Union[str, int] = 'LIST_LONG',
                      sort_method: typing.Union[str, int] = 'FILE_SORT_TIME'):
    '''Open an automatically saved file to recover it 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    '''

    pass


def recover_last_session():
    '''Open the last closed file (“quit.blend”) 

    '''

    pass


def redraw_timer(type: typing.Union[str, int] = 'DRAW',
                 iterations: int = 10,
                 time_limit: float = 0.0):
    '''Simple redraw timer to test the speed of updating the interface 

    :param type: TypeDRAW Draw Region, Draw Region.DRAW_SWAP Draw Region + Swap, Draw Region and Swap.DRAW_WIN Draw Window, Draw Window.DRAW_WIN_SWAP Draw Window + Swap, Draw Window and Swap.ANIM_STEP Anim Step, Animation Steps.ANIM_PLAY Anim Play, Animation Playback.UNDO Undo/Redo, Undo/Redo. 
    :type type: typing.Union[str, int]
    :param iterations: Iterations, Number of times to redraw 
    :type iterations: int
    :param time_limit: Time Limit, Seconds to run the test for (override iterations) 
    :type time_limit: float
    '''

    pass


def revert_mainfile(use_scripts: bool = True):
    '''Reload the saved file 

    :param use_scripts: Trusted Source, Allow .blend file to execute scripts automatically, default available from system preferences 
    :type use_scripts: bool
    '''

    pass


def save_as_mainfile(filepath: str = "",
                     check_existing: bool = True,
                     filter_blender: bool = True,
                     filter_backup: bool = False,
                     filter_image: bool = False,
                     filter_movie: bool = False,
                     filter_python: bool = False,
                     filter_font: bool = False,
                     filter_sound: bool = False,
                     filter_text: bool = False,
                     filter_btx: bool = False,
                     filter_collada: bool = False,
                     filter_alembic: bool = False,
                     filter_folder: bool = True,
                     filter_blenlib: bool = False,
                     filemode: int = 8,
                     display_type: typing.Union[str, int] = 'DEFAULT',
                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                     compress: bool = False,
                     relative_remap: bool = True,
                     copy: bool = False,
                     use_mesh_compat: bool = False):
    '''Save the current file in the desired location 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param compress: Compress, Write compressed .blend file 
    :type compress: bool
    :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory 
    :type relative_remap: bool
    :param copy: Save Copy, Save a copy of the actual working state but does not make saved file active 
    :type copy: bool
    :param use_mesh_compat: Legacy Mesh Format, Save using legacy mesh format (no ngons) - WARNING: only saves tris and quads, other ngons will be lost (no implicit triangulation) 
    :type use_mesh_compat: bool
    '''

    pass


def save_homefile():
    '''Make the current file the default .blend file, includes preferences 

    '''

    pass


def save_mainfile(filepath: str = "",
                  check_existing: bool = True,
                  filter_blender: bool = True,
                  filter_backup: bool = False,
                  filter_image: bool = False,
                  filter_movie: bool = False,
                  filter_python: bool = False,
                  filter_font: bool = False,
                  filter_sound: bool = False,
                  filter_text: bool = False,
                  filter_btx: bool = False,
                  filter_collada: bool = False,
                  filter_alembic: bool = False,
                  filter_folder: bool = True,
                  filter_blenlib: bool = False,
                  filemode: int = 8,
                  display_type: typing.Union[str, int] = 'DEFAULT',
                  sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
                  compress: bool = False,
                  relative_remap: bool = False):
    '''Save the current Blender file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param compress: Compress, Write compressed .blend file 
    :type compress: bool
    :param relative_remap: Remap Relative, Remap relative paths when saving in a different directory 
    :type relative_remap: bool
    '''

    pass


def save_userpref():
    '''Save user preferences separately, overrides startup file preferences 

    '''

    pass


def search_menu():
    '''Pop-up a search menu over all available operators in current context 

    '''

    pass


def set_stereo_3d(display_mode: typing.Union[str, int] = 'ANAGLYPH',
                  anaglyph_type: typing.Union[str, int] = 'RED_CYAN',
                  interlace_type: typing.Union[str, int] = 'ROW_INTERLEAVED',
                  use_interlace_swap: bool = False,
                  use_sidebyside_crosseyed: bool = False):
    '''Toggle 3D stereo support for current window (or change the display mode) 

    :param display_mode: Display ModeANAGLYPH Anaglyph, Render views for left and right eyes as two differently filtered colors in a single image (anaglyph glasses are required).INTERLACE Interlace, Render views for left and right eyes interlaced in a single image (3D-ready monitor is required).TIMESEQUENTIAL Time Sequential, Render alternate eyes (also known as page flip, quad buffer support in the graphic card is required).SIDEBYSIDE Side-by-Side, Render views for left and right eyes side-by-side.TOPBOTTOM Top-Bottom, Render views for left and right eyes one above another. 
    :type display_mode: typing.Union[str, int]
    :param anaglyph_type: Anaglyph Type 
    :type anaglyph_type: typing.Union[str, int]
    :param interlace_type: Interlace Type 
    :type interlace_type: typing.Union[str, int]
    :param use_interlace_swap: Swap Left/Right, Swap left and right stereo channels 
    :type use_interlace_swap: bool
    :param use_sidebyside_crosseyed: Cross-Eyed, Right eye should see left image and vice-versa 
    :type use_sidebyside_crosseyed: bool
    '''

    pass


def splash():
    '''Open the splash screen with release info 

    '''

    pass


def sysinfo(filepath: str = ""):
    '''Generate system information, saved into a text file 

    :param filepath: filepath 
    :type filepath: str
    '''

    pass


def theme_install(overwrite: bool = True,
                  filepath: str = "",
                  filter_folder: bool = True,
                  filter_glob: str = "*.xml"):
    '''Load and apply a Blender XML theme file 

    :param overwrite: Overwrite, Remove existing theme file if exists 
    :type overwrite: bool
    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_glob: filter_glob 
    :type filter_glob: str
    '''

    pass


def url_open(url: str = ""):
    '''Open a website in the web-browser 

    :param url: URL, URL to open 
    :type url: str
    '''

    pass


def userpref_autoexec_path_add():
    '''Add path to exclude from autoexecution 

    '''

    pass


def userpref_autoexec_path_remove(index: int = 0):
    '''Remove path to exclude from autoexecution 

    :param index: Index 
    :type index: int
    '''

    pass


def window_close():
    '''Close the current Blender window 

    '''

    pass


def window_duplicate():
    '''Duplicate the current Blender window 

    '''

    pass


def window_fullscreen_toggle():
    '''Toggle the current window fullscreen 

    '''

    pass



import sys
import typing
import bpy


def actuator_add(type: typing.Union[str, int] = '',
                 name: str = "",
                 object: str = ""):
    '''Add an actuator to the active object 

    :param type: Type, Type of actuator to add 
    :type type: typing.Union[str, int]
    :param name: Name, Name of the Actuator to add 
    :type name: str
    :param object: Object, Name of the Object to add the Actuator to 
    :type object: str
    '''

    pass


def actuator_move(actuator: str = "",
                  object: str = "",
                  direction: typing.Union[str, int] = 'UP'):
    '''Move Actuator 

    :param actuator: Actuator, Name of the actuator to edit 
    :type actuator: str
    :param object: Object, Name of the object the actuator belongs to 
    :type object: str
    :param direction: Direction, Move Up or Down 
    :type direction: typing.Union[str, int]
    '''

    pass


def actuator_remove(actuator: str = "", object: str = ""):
    '''Remove an actuator from the active object 

    :param actuator: Actuator, Name of the actuator to edit 
    :type actuator: str
    :param object: Object, Name of the object the actuator belongs to 
    :type object: str
    '''

    pass


def controller_add(type: typing.Union[str, int] = 'LOGIC_AND',
                   name: str = "",
                   object: str = ""):
    '''Add a controller to the active object 

    :param type: Type, Type of controller to addLOGIC_AND And, Logic And.LOGIC_OR Or, Logic Or.LOGIC_NAND Nand, Logic Nand.LOGIC_NOR Nor, Logic Nor.LOGIC_XOR Xor, Logic Xor.LOGIC_XNOR Xnor, Logic Xnor.EXPRESSION Expression.PYTHON Python. 
    :type type: typing.Union[str, int]
    :param name: Name, Name of the Controller to add 
    :type name: str
    :param object: Object, Name of the Object to add the Controller to 
    :type object: str
    '''

    pass


def controller_move(controller: str = "",
                    object: str = "",
                    direction: typing.Union[str, int] = 'UP'):
    '''Move Controller 

    :param controller: Controller, Name of the controller to edit 
    :type controller: str
    :param object: Object, Name of the object the controller belongs to 
    :type object: str
    :param direction: Direction, Move Up or Down 
    :type direction: typing.Union[str, int]
    '''

    pass


def controller_remove(controller: str = "", object: str = ""):
    '''Remove a controller from the active object 

    :param controller: Controller, Name of the controller to edit 
    :type controller: str
    :param object: Object, Name of the object the controller belongs to 
    :type object: str
    '''

    pass


def links_cut(path: typing.List['bpy.types.OperatorMousePath'] = None,
              cursor: int = 9):
    '''Remove logic brick connections 

    :param path: path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param cursor: Cursor 
    :type cursor: int
    '''

    pass


def properties():
    '''Toggle the properties region visibility 

    '''

    pass


def sensor_add(type: typing.Union[str, int] = '',
               name: str = "",
               object: str = ""):
    '''Add a sensor to the active object 

    :param type: Type, Type of sensor to add 
    :type type: typing.Union[str, int]
    :param name: Name, Name of the Sensor to add 
    :type name: str
    :param object: Object, Name of the Object to add the Sensor to 
    :type object: str
    '''

    pass


def sensor_move(sensor: str = "",
                object: str = "",
                direction: typing.Union[str, int] = 'UP'):
    '''Move Sensor 

    :param sensor: Sensor, Name of the sensor to edit 
    :type sensor: str
    :param object: Object, Name of the object the sensor belongs to 
    :type object: str
    :param direction: Direction, Move Up or Down 
    :type direction: typing.Union[str, int]
    '''

    pass


def sensor_remove(sensor: str = "", object: str = ""):
    '''Remove a sensor from the active object 

    :param sensor: Sensor, Name of the sensor to edit 
    :type sensor: str
    :param object: Object, Name of the object the sensor belongs to 
    :type object: str
    '''

    pass


def view_all():
    '''Resize view so you can see all logic bricks 

    '''

    pass



import sys
import typing


def primitive_nurbs_surface_circle_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Circle 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_surface_curve_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Curve 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_surface_cylinder_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Cylinder 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_surface_sphere_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Sphere 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_surface_surface_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Patch 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_surface_torus_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs surface Torus 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass



import sys
import typing


def change_frame(frame: float = 0.0, snap: bool = False):
    '''Interactively change the current frame number 

    :param frame: Frame 
    :type frame: float
    :param snap: Snap 
    :type snap: bool
    '''

    pass


def channel_select_keys(extend: bool = False):
    '''Select all keyframes of channel under mouse 

    :param extend: Extend, Extend selection 
    :type extend: bool
    '''

    pass


def channels_clean_empty():
    '''Delete all empty animation data containers from visible data-blocks 

    '''

    pass


def channels_click(extend: bool = False, children_only: bool = False):
    '''Handle mouse-clicks over animation channels 

    :param extend: Extend Select 
    :type extend: bool
    :param children_only: Select Children Only 
    :type children_only: bool
    '''

    pass


def channels_collapse(all: bool = True):
    '''Collapse (i.e. close) all selected expandable animation channels 

    :param all: All, Collapse all channels (not just selected ones) 
    :type all: bool
    '''

    pass


def channels_delete():
    '''Delete all selected animation channels 

    '''

    pass


def channels_editable_toggle(mode: typing.Union[str, int] = 'TOGGLE',
                             type: typing.Union[str, int] = 'PROTECT'):
    '''Toggle editability of selected channels 

    :param mode: Mode 
    :type mode: typing.Union[str, int]
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def channels_expand(all: bool = True):
    '''Expand (i.e. open) all selected expandable animation channels 

    :param all: All, Expand all channels (not just selected ones) 
    :type all: bool
    '''

    pass


def channels_fcurves_enable():
    '''Clears ‘disabled’ tag from all F-Curves to get broken F-Curves working again 

    '''

    pass


def channels_find(query: str = "Query"):
    '''Filter the set of channels shown to only include those with matching names 

    :param query: Text to search for in channel names 
    :type query: str
    '''

    pass


def channels_group(name: str = "NewGroup"):
    '''Add selected F-Curves to a new group 

    :param name: Name, Name of newly created group 
    :type name: str
    '''

    pass


def channels_move(direction: typing.Union[str, int] = 'DOWN'):
    '''Rearrange selected animation channels 

    :param direction: Direction 
    :type direction: typing.Union[str, int]
    '''

    pass


def channels_rename():
    '''Rename animation channel under mouse 

    '''

    pass


def channels_select_all_toggle(invert: bool = False):
    '''Toggle selection of all animation channels 

    :param invert: Invert 
    :type invert: bool
    '''

    pass


def channels_select_border(gesture_mode: int = 0,
                           xmin: int = 0,
                           xmax: int = 0,
                           ymin: int = 0,
                           ymax: int = 0,
                           extend: bool = True):
    '''Select all animation channels within the specified region 

    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    '''

    pass


def channels_setting_disable(mode: typing.Union[str, int] = 'DISABLE',
                             type: typing.Union[str, int] = 'PROTECT'):
    '''Disable specified setting on all selected animation channels 

    :param mode: Mode 
    :type mode: typing.Union[str, int]
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def channels_setting_enable(mode: typing.Union[str, int] = 'ENABLE',
                            type: typing.Union[str, int] = 'PROTECT'):
    '''Enable specified setting on all selected animation channels 

    :param mode: Mode 
    :type mode: typing.Union[str, int]
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def channels_setting_toggle(mode: typing.Union[str, int] = 'TOGGLE',
                            type: typing.Union[str, int] = 'PROTECT'):
    '''Toggle specified setting on all selected animation channels 

    :param mode: Mode 
    :type mode: typing.Union[str, int]
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def channels_ungroup():
    '''Remove selected F-Curves from their current groups 

    '''

    pass


def clear_useless_actions(only_unused: bool = True):
    '''Mark actions with no F-Curves for deletion after save & reload of file preserving “action libraries” 

    :param only_unused: Only Unused, Only unused (Fake User only) actions get considered 
    :type only_unused: bool
    '''

    pass


def copy_driver_button():
    '''Copy the driver for the highlighted button 

    '''

    pass


def driver_button_add(mapping_type: typing.Union[str, int] = 'SINGLE_MANY'):
    '''Add driver(s) for the property(s) represented by the highlighted button 

    :param mapping_type: Mapping Type, Method used to match target and driven propertiesSINGLE_MANY All from Target, Drive all components of this property using the target picked.DIRECT Single from Target, Drive this component of this property using the target picked.MATCH Match Indices, Create drivers for each pair of corresponding elements.NONE_ALL Manually Create Later, Create drivers for all properties without assigning any targets yet.NONE_SINGLE Manually Create Later (Single), Create driver for this property only and without assigning any targets yet. 
    :type mapping_type: typing.Union[str, int]
    '''

    pass


def driver_button_remove(all: bool = True):
    '''Remove the driver(s) for the property(s) connected represented by the highlighted button 

    :param all: All, Delete drivers for all elements of the array 
    :type all: bool
    '''

    pass


def keyframe_clear_button(all: bool = True):
    '''Clear all keyframes on the currently active property 

    :param all: All, Clear keyframes from all elements of the array 
    :type all: bool
    '''

    pass


def keyframe_clear_v3d():
    '''Remove all keyframe animation for selected objects 

    '''

    pass


def keyframe_delete(type: typing.Union[str, int] = 'DEFAULT',
                    confirm_success: bool = True):
    '''Delete keyframes on the current frame for all properties in the specified Keying Set 

    :param type: Keying Set, The Keying Set to use 
    :type type: typing.Union[str, int]
    :param confirm_success: Confirm Successful Delete, Show a popup when the keyframes get successfully removed 
    :type confirm_success: bool
    '''

    pass


def keyframe_delete_button(all: bool = True):
    '''Delete current keyframe of current UI-active property 

    :param all: All, Delete keyframes from all elements of the array 
    :type all: bool
    '''

    pass


def keyframe_delete_v3d():
    '''Remove keyframes on current frame for selected objects and bones 

    '''

    pass


def keyframe_insert(type: typing.Union[str, int] = 'DEFAULT',
                    confirm_success: bool = True):
    '''Insert keyframes on the current frame for all properties in the specified Keying Set 

    :param type: Keying Set, The Keying Set to use 
    :type type: typing.Union[str, int]
    :param confirm_success: Confirm Successful Insert, Show a popup when the keyframes get successfully added 
    :type confirm_success: bool
    '''

    pass


def keyframe_insert_button(all: bool = True):
    '''Insert a keyframe for current UI-active property 

    :param all: All, Insert a keyframe for all element of the array 
    :type all: bool
    '''

    pass


def keyframe_insert_menu(type: typing.Union[str, int] = 'DEFAULT',
                         confirm_success: bool = False,
                         always_prompt: bool = False):
    '''Insert Keyframes for specified Keying Set, with menu of available Keying Sets if undefined 

    :param type: Keying Set, The Keying Set to use 
    :type type: typing.Union[str, int]
    :param confirm_success: Confirm Successful Insert, Show a popup when the keyframes get successfully added 
    :type confirm_success: bool
    :param always_prompt: Always Show Menu 
    :type always_prompt: bool
    '''

    pass


def keying_set_active_set(type: typing.Union[str, int] = 'DEFAULT'):
    '''Select a new keying set as the active one 

    :param type: Keying Set, The Keying Set to use 
    :type type: typing.Union[str, int]
    '''

    pass


def keying_set_add():
    '''Add a new (empty) Keying Set to the active Scene 

    '''

    pass


def keying_set_export(filepath: str = "",
                      filter_folder: bool = True,
                      filter_text: bool = True,
                      filter_python: bool = True):
    '''Export Keying Set to a python script 

    :param filepath: filepath 
    :type filepath: str
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_text: Filter text 
    :type filter_text: bool
    :param filter_python: Filter python 
    :type filter_python: bool
    '''

    pass


def keying_set_path_add():
    '''Add empty path to active Keying Set 

    '''

    pass


def keying_set_path_remove():
    '''Remove active Path from active Keying Set 

    '''

    pass


def keying_set_remove():
    '''Remove the active Keying Set 

    '''

    pass


def keyingset_button_add(all: bool = True):
    '''Add current UI-active property to current keying set 

    :param all: All, Add all elements of the array to a Keying Set 
    :type all: bool
    '''

    pass


def keyingset_button_remove():
    '''Remove current UI-active property from current keying set 

    '''

    pass


def paste_driver_button():
    '''Paste the driver in the copy/paste buffer for the highlighted button 

    '''

    pass


def previewrange_clear():
    '''Clear Preview Range 

    '''

    pass


def previewrange_set(xmin: int = 0,
                     xmax: int = 0,
                     ymin: int = 0,
                     ymax: int = 0):
    '''Interactively define frame range used for playback 

    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    '''

    pass


def update_animated_transform_constraints(use_convert_to_radians: bool = True):
    '''Update fcurves/drivers affecting Transform constraints (use it with files from 2.70 and earlier) 

    :param use_convert_to_radians: Convert To Radians, Convert fcurves/drivers affecting rotations to radians (Warning: use this only once!) 
    :type use_convert_to_radians: bool
    '''

    pass



import sys
import typing


class PropertyPanel:
    bl_label = None
    ''''''

    bl_options = None
    ''''''

    def draw(self, context):
        '''

        '''
        pass

    def poll(self, context):
        '''

        '''
        pass


def draw(layout, context, context_member, property_type, use_edit):
    '''

    '''

    pass


def rna_idprop_context_value(context, context_member, property_type):
    '''

    '''

    pass


def rna_idprop_has_properties(rna_item):
    '''

    '''

    pass


def rna_idprop_ui_del(item):
    '''

    '''

    pass


def rna_idprop_ui_get(item, create):
    '''

    '''

    pass


def rna_idprop_ui_prop_clear(item, prop, remove):
    '''

    '''

    pass


def rna_idprop_ui_prop_get(item, prop, create):
    '''

    '''

    pass


def rna_idprop_ui_prop_update(item, prop):
    '''

    '''

    pass



import sys
import typing


def copy_data_path_button(full_path: bool = False):
    '''Copy the RNA data path for this property to the clipboard 

    :param full_path: full_path, Copy full data path 
    :type full_path: bool
    '''

    pass


def copy_python_command_button():
    '''Copy the Python command matching this button 

    '''

    pass


def copy_to_selected_button(all: bool = True):
    '''Copy property from this object to selected objects or bones 

    :param all: All, Copy to selected all elements of the array 
    :type all: bool
    '''

    pass


def drop_color(color: float = (0.0, 0.0, 0.0), gamma: bool = False):
    '''Drop colors to buttons 

    :param color: Color, Source color 
    :type color: float
    :param gamma: Gamma Corrected, The source color is gamma corrected 
    :type gamma: bool
    '''

    pass


def editsource():
    '''Edit UI source code of the active button 

    '''

    pass


def edittranslation_init():
    '''Edit i18n in current language for the active button 

    '''

    pass


def eyedropper_color():
    '''Sample a color from the Blender Window to store in a property 

    '''

    pass


def eyedropper_depth():
    '''Sample depth from the 3D view 

    '''

    pass


def eyedropper_driver(mapping_type: typing.Union[str, int] = 'SINGLE_MANY'):
    '''Pick a property to use as a driver target 

    :param mapping_type: Mapping Type, Method used to match target and driven propertiesSINGLE_MANY All from Target, Drive all components of this property using the target picked.DIRECT Single from Target, Drive this component of this property using the target picked.MATCH Match Indices, Create drivers for each pair of corresponding elements.NONE_ALL Manually Create Later, Create drivers for all properties without assigning any targets yet.NONE_SINGLE Manually Create Later (Single), Create driver for this property only and without assigning any targets yet. 
    :type mapping_type: typing.Union[str, int]
    '''

    pass


def eyedropper_id():
    '''Sample a data-block from the 3D View to store in a property 

    '''

    pass


def reloadtranslation():
    '''Force a full reload of UI translation 

    '''

    pass


def reports_to_textblock():
    '''Write the reports 

    '''

    pass


def reset_default_button(all: bool = True):
    '''Reset this property’s value to its default value 

    :param all: All, Reset to default values all elements of the array 
    :type all: bool
    '''

    pass


def reset_default_theme():
    '''Reset to the default theme colors 

    '''

    pass


def unset_property_button():
    '''Clear the property and use default or generated value in operators 

    '''

    pass



import sys
import typing


def preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Safe Areas Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass



import sys
import typing


def bake_animation():
    '''Update the audio animation cache 

    '''

    pass


def mixdown(filepath: str = "",
            check_existing: bool = True,
            filter_blender: bool = False,
            filter_backup: bool = False,
            filter_image: bool = False,
            filter_movie: bool = False,
            filter_python: bool = False,
            filter_font: bool = False,
            filter_sound: bool = True,
            filter_text: bool = False,
            filter_btx: bool = False,
            filter_collada: bool = False,
            filter_alembic: bool = False,
            filter_folder: bool = True,
            filter_blenlib: bool = False,
            filemode: int = 9,
            relative_path: bool = True,
            display_type: typing.Union[str, int] = 'DEFAULT',
            sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
            accuracy: int = 1024,
            container: typing.Union[str, int] = 'FLAC',
            codec: typing.Union[str, int] = 'FLAC',
            format: typing.Union[str, int] = 'S16',
            bitrate: int = 192,
            split_channels: bool = False):
    '''Mix the scene’s audio to a sound file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param accuracy: Accuracy, Sample accuracy, important for animation data (the lower the value, the more accurate) 
    :type accuracy: int
    :param container: Container, File formatAC3 ac3, Dolby Digital ATRAC 3.FLAC flac, Free Lossless Audio Codec.MATROSKA mkv, Matroska.MP2 mp2, MPEG-1 Audio Layer II.MP3 mp3, MPEG-2 Audio Layer III.OGG ogg, Xiph.Org Ogg Container.WAV wav, Waveform Audio File Format. 
    :type container: typing.Union[str, int]
    :param codec: Codec, Audio CodecAAC AAC, Advanced Audio Coding.AC3 AC3, Dolby Digital ATRAC 3.FLAC FLAC, Free Lossless Audio Codec.MP2 MP2, MPEG-1 Audio Layer II.MP3 MP3, MPEG-2 Audio Layer III.PCM PCM, Pulse Code Modulation (RAW).VORBIS Vorbis, Xiph.Org Vorbis Codec. 
    :type codec: typing.Union[str, int]
    :param format: Format, Sample formatU8 U8, 8 bit unsigned.S16 S16, 16 bit signed.S24 S24, 24 bit signed.S32 S32, 32 bit signed.F32 F32, 32 bit floating point.F64 F64, 64 bit floating point. 
    :type format: typing.Union[str, int]
    :param bitrate: Bitrate, Bitrate in kbit/s 
    :type bitrate: int
    :param split_channels: Split channels, Each channel will be rendered into a mono file 
    :type split_channels: bool
    '''

    pass


def open(filepath: str = "",
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
         filter_movie: bool = True,
         filter_python: bool = False,
         filter_font: bool = False,
         filter_sound: bool = True,
         filter_text: bool = False,
         filter_btx: bool = False,
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
         display_type: typing.Union[str, int] = 'DEFAULT',
         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
         cache: bool = False,
         mono: bool = False):
    '''Load a sound file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param show_multiview: Enable Multi-View 
    :type show_multiview: bool
    :param use_multiview: Use Multi-View 
    :type use_multiview: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param cache: Cache, Cache the sound in memory 
    :type cache: bool
    :param mono: Mono, Merge all the sound’s channels into one 
    :type mono: bool
    '''

    pass


def open_mono(filepath: str = "",
              filter_blender: bool = False,
              filter_backup: bool = False,
              filter_image: bool = False,
              filter_movie: bool = True,
              filter_python: bool = False,
              filter_font: bool = False,
              filter_sound: bool = True,
              filter_text: bool = False,
              filter_btx: bool = False,
              filter_collada: bool = False,
              filter_alembic: bool = False,
              filter_folder: bool = True,
              filter_blenlib: bool = False,
              filemode: int = 9,
              relative_path: bool = True,
              show_multiview: bool = False,
              use_multiview: bool = False,
              display_type: typing.Union[str, int] = 'DEFAULT',
              sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
              cache: bool = False,
              mono: bool = True):
    '''Load a sound file as mono 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param show_multiview: Enable Multi-View 
    :type show_multiview: bool
    :param use_multiview: Use Multi-View 
    :type use_multiview: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param cache: Cache, Cache the sound in memory 
    :type cache: bool
    :param mono: Mono, Mixdown the sound to mono 
    :type mono: bool
    '''

    pass


def pack():
    '''Pack the sound into the current blend file 

    '''

    pass


def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
    '''Unpack the sound to the samples filename 

    :param method: Method, How to unpack 
    :type method: typing.Union[str, int]
    :param id: Sound Name, Sound data-block name to unpack 
    :type id: str
    '''

    pass


def update_animation_flags():
    '''Update animation flags 

    '''

    pass



import sys
import typing


def childof_clear_inverse(constraint: str = "",
                          owner: typing.Union[str, int] = 'OBJECT'):
    '''Clear inverse correction for ChildOf constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def childof_set_inverse(constraint: str = "",
                        owner: typing.Union[str, int] = 'OBJECT'):
    '''Set inverse correction for ChildOf constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def delete():
    '''Remove constraint from constraint stack 

    '''

    pass


def followpath_path_animate(constraint: str = "",
                            owner: typing.Union[str, int] = 'OBJECT',
                            frame_start: int = 1,
                            length: int = 100):
    '''Add default animation for path used by constraint if it isn’t animated already 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    :param frame_start: Start Frame, First frame of path animation 
    :type frame_start: int
    :param length: Length, Number of frames that path animation should take 
    :type length: int
    '''

    pass


def limitdistance_reset(constraint: str = "",
                        owner: typing.Union[str, int] = 'OBJECT'):
    '''Reset limiting distance for Limit Distance Constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def move_down(constraint: str = "", owner: typing.Union[str, int] = 'OBJECT'):
    '''Move constraint down in constraint stack 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def move_up(constraint: str = "", owner: typing.Union[str, int] = 'OBJECT'):
    '''Move constraint up in constraint stack 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def objectsolver_clear_inverse(constraint: str = "",
                               owner: typing.Union[str, int] = 'OBJECT'):
    '''Clear inverse correction for ObjectSolver constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def objectsolver_set_inverse(constraint: str = "",
                             owner: typing.Union[str, int] = 'OBJECT'):
    '''Set inverse correction for ObjectSolver constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass


def stretchto_reset(constraint: str = "",
                    owner: typing.Union[str, int] = 'OBJECT'):
    '''Reset original length of bone for Stretch To Constraint 

    :param constraint: Constraint, Name of the constraint to edit 
    :type constraint: str
    :param owner: Owner, The owner of this constraintOBJECT Object, Edit a constraint on the active object.BONE Bone, Edit a constraint on the active bone. 
    :type owner: typing.Union[str, int]
    '''

    pass



import sys
import typing


class Device:
    '''Unlocks the device after a lock call, see lock() for details. '''

    channels = None
    '''The channel count of the device. '''

    distance_model = None
    '''The distance model of the device. '''

    doppler_factor = None
    '''The doppler factor of the device. This factor is a scaling factor for the velocity vectors in doppler calculation. So a value bigger than 1 will exaggerate the effect as it raises the velocity. '''

    format = None
    '''The native sample format of the device. '''

    listener_location = None
    '''The listeners’s location in 3D space, a 3D tuple of floats. '''

    listener_orientation = None
    '''The listener’s orientation in 3D space as quaternion, a 4 float tuple. '''

    listener_velocity = None
    '''The listener’s velocity in 3D space, a 3D tuple of floats. '''

    rate = None
    '''The sampling rate of the device in Hz. '''

    speed_of_sound = None
    '''The speed of sound of the device. The speed of sound in air is typically 343.3 m/s. '''

    volume = None
    '''The overall volume of the device. '''


class Factory:
    '''Changes the volume of a factory. '''

    pass


class Handle:
    '''Stops playback. '''

    attenuation = None
    '''This factor is used for distance based attenuation of the source. '''

    cone_angle_inner = None
    '''The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the location of the source and with infinite height, heading in the direction of the source’s orientation. In the inner cone the volume is normal. Outside the outer cone the volume will be cone_volume_outer and in the area between the volume will be interpolated linearly. '''

    cone_angle_outer = None
    '''The opening angle of the outer cone of the source. '''

    cone_volume_outer = None
    '''The volume outside the outer cone of the source. '''

    distance_maximum = None
    '''The maximum distance of the source. If the listener is further away the source volume will be 0. '''

    distance_reference = None
    '''The reference distance of the source. At this distance the volume will be exactly volume. '''

    keep = None
    '''Whether the sound should be kept paused in the device when its end is reached. This can be used to seek the sound to some position and start playback again. '''

    location = None
    '''The source’s location in 3D space, a 3D tuple of floats. '''

    loop_count = None
    '''The (remaining) loop count of the sound. A negative value indicates infinity. '''

    orientation = None
    '''The source’s orientation in 3D space as quaternion, a 4 float tuple. '''

    pitch = None
    '''The pitch of the sound. '''

    position = None
    '''The playback position of the sound in seconds. '''

    relative = None
    '''Whether the source’s location, velocity and orientation is relative or absolute to the listener. '''

    status = None
    '''Whether the sound is playing, paused or stopped (=invalid). '''

    velocity = None
    '''The source’s velocity in 3D space, a 3D tuple of floats. '''

    volume = None
    '''The volume of the sound. '''

    volume_maximum = None
    '''The maximum volume of the source. '''

    volume_minimum = None
    '''The minimum volume of the source. '''


class error:
    pass


AUD_DEVICE_JACK = None
'''constant value 3 '''

AUD_DEVICE_NULL = None
'''constant value 0 '''

AUD_DEVICE_OPENAL = None
'''constant value 1 '''

AUD_DEVICE_SDL = None
'''constant value 2 '''

AUD_DISTANCE_MODEL_EXPONENT = None
'''constant value 5 '''

AUD_DISTANCE_MODEL_EXPONENT_CLAMPED = None
'''constant value 6 '''

AUD_DISTANCE_MODEL_INVALID = None
'''constant value 0 '''

AUD_DISTANCE_MODEL_INVERSE = None
'''constant value 1 '''

AUD_DISTANCE_MODEL_INVERSE_CLAMPED = None
'''constant value 2 '''

AUD_DISTANCE_MODEL_LINEAR = None
'''constant value 3 '''

AUD_DISTANCE_MODEL_LINEAR_CLAMPED = None
'''constant value 4 '''

AUD_FORMAT_FLOAT32 = None
'''constant value 36 '''

AUD_FORMAT_FLOAT64 = None
'''constant value 40 '''

AUD_FORMAT_INVALID = None
'''constant value 0 '''

AUD_FORMAT_S16 = None
'''constant value 18 '''

AUD_FORMAT_S24 = None
'''constant value 19 '''

AUD_FORMAT_S32 = None
'''constant value 20 '''

AUD_FORMAT_U8 = None
'''constant value 1 '''

AUD_STATUS_INVALID = None
'''constant value 0 '''

AUD_STATUS_PAUSED = None
'''constant value 2 '''

AUD_STATUS_PLAYING = None
'''constant value 1 '''

AUD_STATUS_STOPPED = None
'''constant value 3 '''



import sys
import typing


def end_frame_set():
    '''Set the end frame 

    '''

    pass


def start_frame_set():
    '''Set the start frame 

    '''

    pass


def view_all():
    '''Show the entire playable frame range 

    '''

    pass


def view_frame():
    '''Reset viewable area to show range around current frame 

    '''

    pass



import sys
import typing


def report_copy():
    '''Copy selected reports to Clipboard 

    '''

    pass


def report_delete():
    '''Delete selected reports 

    '''

    pass


def report_replay():
    '''Replay selected reports 

    '''

    pass


def reports_display_update():
    '''Update the display of reports in Blender UI (internal use) 

    '''

    pass


def select_all_toggle():
    '''Select or deselect all reports 

    '''

    pass


def select_border(gesture_mode: int = 0,
                  xmin: int = 0,
                  xmax: int = 0,
                  ymin: int = 0,
                  ymax: int = 0,
                  extend: bool = True):
    '''Toggle border selection 

    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    '''

    pass


def select_pick(report_index: int = 0):
    '''Select reports by index 

    :param report_index: Report, Index of the report 
    :type report_index: int
    '''

    pass



import sys
import typing
import freestyle


def get_border():
    '''Returns the border. 

    :return:  A tuple of 4 numbers (xmin, ymin, xmax, ymax). 
    '''

    pass


def get_canvas_height() -> int:
    '''Returns the canvas height. 

    :return:  The canvas height. 
    '''

    pass


def get_canvas_width() -> int:
    '''Returns the canvas width. 

    :return:  The canvas width. 
    '''

    pass


def get_selected_fedge() -> 'freestyle.types.FEdge':
    '''Returns the selected FEdge. 

    :return:  The selected FEdge. 
    '''

    pass


def get_time_stamp() -> int:
    '''Returns the system time stamp. 

    :return:  The system time stamp. 
    '''

    pass


def load_map(file_name: str,
             map_name: str,
             num_levels: int = 4,
             sigma: float = 1.0):
    '''Loads an image map for further reading. 

    :param file_name: The name of the image file. 
    :type file_name: str
    :param map_name: The name that will be used to access this image. 
    :type map_name: str
    :param num_levels: The number of levels in the map pyramid (default = 4). If num_levels == 0, the complete pyramid is built. 
    :type num_levels: int
    :param sigma: The sigma value of the gaussian function. 
    :type sigma: float
    '''

    pass


def read_complete_view_map_pixel(level: int, x: int, y: int) -> float:
    '''Reads a pixel in the complete view map. 

    :param level: The level of the pyramid in which we wish to read the pixel. 
    :type level: int
    :param x: The x coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type x: int
    :param y: The y coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type y: int
    :return:  The floating-point value stored for that pixel. 
    '''

    pass


def read_directional_view_map_pixel(orientation: int, level: int, x: int,
                                    y: int) -> float:
    '''Reads a pixel in one of the oriented view map images. 

    :param orientation: The number telling which orientation we want to check. 
    :type orientation: int
    :param level: The level of the pyramid in which we wish to read the pixel. 
    :type level: int
    :param x: The x coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type x: int
    :param y: The y coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type y: int
    :return:  The floating-point value stored for that pixel. 
    '''

    pass


def read_map_pixel(map_name: str, level: int, x: int, y: int) -> float:
    '''Reads a pixel in a user-defined map. 

    :param map_name: The name of the map. 
    :type map_name: str
    :param level: The level of the pyramid in which we wish to read the pixel. 
    :type level: int
    :param x: The x coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type x: int
    :param y: The y coordinate of the pixel we wish to read. The origin is in the lower-left corner. 
    :type y: int
    :return:  The floating-point value stored for that pixel. 
    '''

    pass
